@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2010 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,65 +27,82 @@
 
 #include <arvtypes.h>
 
-#include <arvfeatures.h>
-#include <arvversion.h>
+#include <arvbuffer.h>
+#include <arvcamera.h>
+#include <arvchunkparser.h>
 #include <arvdebug.h>
-#include <arvmisc.h>
-#include <arvstr.h>
-#include <arvzip.h>
-#include <arvsystem.h>
-#include <arvevaluator.h>
-#include <arvdomnode.h>
-#include <arvdomnodelist.h>
+#include <arvdevice.h>
+
+#include <arvdomcharacterdata.h>
+#include <arvdomdocumentfragment.h>
 #include <arvdomdocument.h>
 #include <arvdomelement.h>
-#include <arvdomcharacterdata.h>
-#include <arvdomtext.h>
 #include <arvdomimplementation.h>
+#include <arvdomnamednodemap.h>
+#include <arvdomnode.h>
+#include <arvdomnodelist.h>
 #include <arvdomparser.h>
-#include <arvcamera.h>
-#include <arvgc.h>
-#include <arvgcnode.h>
-#include <arvgcpropertynode.h>
-#include <arvgcfeaturenode.h>
-#include <arvgccategory.h>
+#include <arvdomtext.h>
+
+#include <arvenums.h>
+#include <arvevaluator.h>
+
+#include <arvfakecamera.h>
+#include <arvfakedevice.h>
+#include <arvfakeinterface.h>
+#include <arvfakestream.h>
+
+#include <arvfeatures.h>
+
 #include <arvgcboolean.h>
-#include <arvgcenumeration.h>
-#include <arvgcenumentry.h>
-#include <arvgcintegernode.h>
-#include <arvgcfloatnode.h>
-#include <arvgcregisternode.h>
+#include <arvgccategory.h>
 #include <arvgccommand.h>
-#include <arvgcswissknife.h>
 #include <arvgcconverter.h>
-#include <arvgcport.h>
-#include <arvgcregister.h>
-#include <arvgcinteger.h>
+#include <arvgcconverternode.h>
+#include <arvgcenumentry.h>
+#include <arvgcenumeration.h>
+#include <arvgcenums.h>
+#include <arvgcfeaturenode.h>
 #include <arvgcfloat.h>
+#include <arvgcfloatnode.h>
+#include <arvgcgroupnode.h>
+#include <arvgc.h>
+#include <arvgcindexnode.h>
+#include <arvgcintconverternode.h>
+#include <arvgcinteger.h>
+#include <arvgcintegernode.h>
+#include <arvgcinvalidatornode.h>
+#include <arvgcnode.h>
+#include <arvgcport.h>
+#include <arvgcpropertynode.h>
+#include <arvgcregisterdescriptionnode.h>
+#include <arvgcregister.h>
+#include <arvgcregisternode.h>
 #include <arvgcstring.h>
-#include <arvinterface.h>
-#include <arvdevice.h>
-#include <arvstream.h>
-#include <arvbuffer.h>
-#include <arvchunkparser.h>
-#include <arvgvcp.h>
-#include <arvgvsp.h>
-#include <arvgvinterface.h>
+#include <arvgcstructentrynode.h>
+#include <arvgcswissknife.h>
+#include <arvgcvalueindexednode.h>
+
 #include <arvgvdevice.h>
+#include <arvgvfakecamera.h>
+#include <arvgvinterface.h>
 #include <arvgvstream.h>
-#ifdef ARAVIS_BUILD_USB
-#include <arvuvcp.h>
-#include <arvuvsp.h>
+
+#include <arvinterface.h>
+#include <arvmisc.h>
+#include <arvrealtime.h>
+#include <arvstream.h>
+#include <arvstr.h>
+#include <arvsystem.h>
+
+#if ARAVIS_HAS_USB
 #include <arvuvinterface.h>
 #include <arvuvdevice.h>
 #include <arvuvstream.h>
 #endif
-#include <arvfakeinterface.h>
-#include <arvfakedevice.h>
-#include <arvfakestream.h>
-#include <arvfakecamera.h>
-#include <arvgvfakecamera.h>
-#include <arvrealtime.h>
+
+#include <arvversion.h>
+#include <arvzip.h>
 #include <arvxmlschema.h>
 
 #undef ARV_H_INSIDE
