@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2010 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,6 +35,12 @@ ArvDebugCategory arv_debug_category_interface =
 	.level = -1
 };
 
+ArvDebugCategory arv_debug_category_dom =
+{
+	.name = "dom",
+	.level = -1
+};
+
 ArvDebugCategory arv_debug_category_device =
 {
 	.name = "device",
@@ -89,6 +95,12 @@ ArvDebugCategory arv_debug_category_misc =
 	.level = -1
 };
 
+ArvDebugCategory arv_debug_category_viewer =
+{
+	.name = "viewer",
+	.level = -1
+};
+
 static GHashTable *arv_debug_categories = NULL;
 
 static void
