@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2010 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,27 +31,28 @@
 
 G_BEGIN_DECLS
 
-typedef enum {
-	ARV_GC_NAME_SPACE_STANDARD,
-	ARV_GC_NAME_SPACE_CUSTOM
-} ArvGcNameSpace;
+/**
+ * ArvStatus:
+ * @ARV_STATUS_UNKNOWN: unknown status
+ * @ARV_STATUS_SUCCESS: no error has occured
+ * @ARV_STATUS_TIMEOUT: action failed on a timeout
+ * @ARV_STATUS_WRITE_ERROR: write on a read only node
+ * @ARV_STATUS_TRANSFER_ERROR: error during data transfer
+ * @ARV_STATUS_PROTOCOL_ERROR: protocol specific error
+ * @ARV_STATUS_NOT_CONNECTED: device not connected
+ *
+ * Since: 0.8.0
+ */
 
 typedef enum {
-	ARV_GC_ACCESS_MODE_RO,
-	ARV_GC_ACCESS_MODE_WO,
-	ARV_GC_ACCESS_MODE_RW
-} ArvGcAccessMode;
-
-typedef enum {
-	ARV_GC_CACHABLE_NO_CACHE,
-	ARV_GC_CACHABLE_WRITE_TRHOUGH,
-	ARV_GC_CACHABLE_WRITE_AROUND
-} ArvGcCachable;
-
-typedef enum {
-	ARV_GC_SIGNEDNESS_SIGNED,
-	ARV_GC_SIGNEDNESS_UNSIGNED
-} ArvGcSignedness;
+	ARV_STATUS_UNKNOWN = -1,
+	ARV_STATUS_SUCCESS =  0,
+	ARV_STATUS_TIMEOUT,
+	ARV_STATUS_WRITE_ERROR,
+	ARV_STATUS_TRANSFER_ERROR,
+	ARV_STATUS_PROTOCOL_ERROR,
+	ARV_STATUS_NOT_CONNECTED
+} ArvStatus;
 
 /**
  * ArvAuto:
