@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2012 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -49,19 +49,22 @@
 #include <arvgcfloat.h>
 #include <arvgcboolean.h>
 #include <arvgcswissknife.h>
-#include <arvgcconverter.h>
+#include <arvgcconverternode.h>
+#include <arvgcintconverternode.h>
 #include <arvgcport.h>
 #include <arvbuffer.h>
 #include <arvdebug.h>
 #include <arvdomparser.h>
 #include <string.h>
-
-static GObjectClass *parent_class = NULL;
+#include <stdarg.h>
+#include <stdio.h>
 
 struct _ArvGcPrivate {
 	GHashTable *nodes;
 	ArvDevice *device;
 	ArvBuffer *buffer;
+
+	ArvRegisterCachePolicy cache_policy;
 };
 
 GQuark
@@ -90,9 +93,9 @@ arv_gc_create_element (ArvDomDocument *document, const char *tag_name)
 	else if (strcmp (tag_name, "Command") == 0)
 		node = arv_gc_command_new ();
 	else if (strcmp (tag_name, "Converter") == 0)
-		node = arv_gc_converter_new ();
+		node = arv_gc_converter_node_new ();
 	else if (strcmp (tag_name, "IntConverter") == 0)
-		node = arv_gc_converter_new_integer ();
+		node = arv_gc_int_converter_node_new ();
 	else if (strcmp (tag_name, "Register") == 0)
 		node = arv_gc_register_node_new ();
 	else if (strcmp (tag_name, "IntReg") == 0)
@@ -155,6 +158,10 @@ arv_gc_create_element (ArvDomDocument *document, const char *tag_name)
 		node = arv_gc_property_node_new_increment ();
 	else if (strcmp (tag_name, "pInc") == 0)
 		node = arv_gc_property_node_new_p_increment ();
+	else if (strcmp (tag_name, "IsLinear") == 0)
+		node = arv_gc_property_node_new_is_linear ();
+	else if (strcmp (tag_name, "Slope") == 0)
+		node = arv_gc_property_node_new_slope ();
 	else if (strcmp (tag_name, "Unit") == 0)
 		node = arv_gc_property_node_new_unit ();
 	else if (strcmp (tag_name, "OnValue") == 0)
@@ -290,16 +297,42 @@ arv_gc_register_feature_node (ArvGc *genicam, ArvGcFeatureNode *node)
 }
 
 void
-arv_gc_set_default_node_data (ArvGc *genicam, const char *node_name, const char *node_data)
+arv_gc_set_default_node_data (ArvGc *genicam, const char *node_name, ...)
 {
+	va_list args;
+	char *node_data;
+
 	g_return_if_fail (ARV_IS_GC (genicam));
 	g_return_if_fail (node_name != NULL);
-	g_return_if_fail (node_data != NULL);
 
 	if (arv_gc_get_node (genicam, node_name) != NULL)
 		return;
 
-	arv_dom_document_append_from_memory (ARV_DOM_DOCUMENT (genicam), NULL, node_data, -1, NULL);
+	arv_debug_genicam ("[Gc::set_default_node_data] Add '%s'", node_name);
+
+	va_start (args, node_name);
+	do {
+		node_data = va_arg (args, char *);
+		if (node_data != NULL)
+			arv_dom_document_append_from_memory (ARV_DOM_DOCUMENT (genicam), NULL, node_data, -1, NULL);
+	} while (node_data != NULL);
+	va_end (args);
+}
+
+void
+arv_gc_set_register_cache_policy (ArvGc *genicam, ArvRegisterCachePolicy policy)
+{
+	g_return_if_fail (ARV_IS_GC (genicam));
+
+	genicam->priv->cache_policy = policy;
+}
+
+ArvRegisterCachePolicy
+arv_gc_get_register_cache_policy (ArvGc *genicam)
+{
+	g_return_val_if_fail (ARV_IS_GC (genicam), ARV_REGISTER_CACHE_POLICY_DISABLE);
+
+	return genicam->priv->cache_policy;
 }
 
 static void
@@ -360,12 +393,15 @@ arv_gc_new (ArvDevice *device, const void *xml, size_t size)
 	return genicam;
 }
 
+G_DEFINE_TYPE_WITH_CODE (ArvGc, arv_gc, ARV_TYPE_DOM_DOCUMENT, G_ADD_PRIVATE (ArvGc))
+
 static void
 arv_gc_init (ArvGc *genicam)
 {
-	genicam->priv = G_TYPE_INSTANCE_GET_PRIVATE (genicam, ARV_TYPE_GC, ArvGcPrivate);
+	genicam->priv = arv_gc_get_instance_private (genicam);
 
 	genicam->priv->nodes = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, g_object_unref);
+	genicam->priv->cache_policy = ARV_REGISTER_CACHE_POLICY_DISABLE;
 }
 
 static void
@@ -378,7 +414,7 @@ arv_gc_finalize (GObject *object)
 
 	g_hash_table_unref (genicam->priv->nodes);
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (arv_gc_parent_class)->finalize (object);
 }
 
 static void
@@ -388,19 +424,7 @@ arv_gc_class_init (ArvGcClass *node_class)
 	ArvDomNodeClass *d_node_class = ARV_DOM_NODE_CLASS (node_class);
 	ArvDomDocumentClass *d_document_class = ARV_DOM_DOCUMENT_CLASS (node_class);
 
-#if !GLIB_CHECK_VERSION(2,38,0)
-	g_type_class_add_private (node_class, sizeof (ArvGcPrivate));
-#endif
-
-	parent_class = g_type_class_peek_parent (node_class);
-
 	object_class->finalize = arv_gc_finalize;
 	d_node_class->can_append_child = arv_gc_can_append_child;
 	d_document_class->create_element = arv_gc_create_element;
 }
-
-#if !GLIB_CHECK_VERSION(2,38,0)
-G_DEFINE_TYPE (ArvGc, arv_gc, ARV_TYPE_DOM_DOCUMENT)
-#else
-G_DEFINE_TYPE_WITH_CODE (ArvGc, arv_gc, ARV_TYPE_DOM_DOCUMENT, G_ADD_PRIVATE (ArvGc))
-#endif
