@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2012 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,7 @@
 #include <arvgcenumentry.h>
 #include <arvgcinteger.h>
 #include <arvgcstring.h>
+#include <arvgcfeaturenodeprivate.h>
 #include <arvgc.h>
 #include <arvmisc.h>
 #include <arvdebug.h>
@@ -109,7 +110,7 @@ arv_gc_enumeration_get_value_as_string (ArvGcFeatureNode *node, GError **error)
 GType
 arv_gc_enumeration_get_value_type (ArvGcFeatureNode *node)
 {
-	return G_TYPE_STRING;
+	return G_TYPE_INT64;
 }
 
 
@@ -197,6 +198,10 @@ arv_gc_enumeration_get_int_value (ArvGcEnumeration *enumeration, GError **error)
 {
 	GError *local_error = NULL;
 	gint64 value;
+	gint64 *available_values;
+	unsigned n_values;
+	unsigned i;
+	gboolean found = FALSE;
 
 	g_return_val_if_fail (ARV_IS_GC_ENUMERATION (enumeration), 0);
 	g_return_val_if_fail (error == NULL || *error == NULL, 0);
@@ -211,6 +216,30 @@ arv_gc_enumeration_get_int_value (ArvGcEnumeration *enumeration, GError **error)
 		return 0;
 	}
 
+	available_values = arv_gc_enumeration_get_available_int_values (enumeration, &n_values, &local_error);
+	if (local_error != NULL) {
+		g_propagate_error (error, local_error);
+		return value;
+	}
+
+	if (available_values == NULL) {
+		g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_EMPTY_ENUMERATION,
+			     "No available entry found in <Enumeration> '%s'",
+			     arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (enumeration)));
+		return value;
+	}
+
+	for (i = 0; i < n_values; i++)
+		if (available_values[i] == value)
+			found = TRUE;
+
+	g_free (available_values);
+
+	if (!found)
+		g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_OUT_OF_RANGE,
+			     "Value not found in <Enumeration> '%s'",
+			     arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (enumeration)));
+
 	return value;
 }
 
@@ -292,19 +321,8 @@ arv_gc_enumeration_get_available_int_values (ArvGcEnumeration *enumeration, guin
 	return values;
 }
 
-/**
- * arv_gc_enumeration_get_available_string_values:
- * @enumeration: an #ArvGcEnumeration
- * @n_values: (out): placeholder for the number of values
- * @error: placeholder for error, may be NULL
- *
- * Create an array of all available values of @enumeration, as strings.
- *
- * Returns: (array length=n_values) (transfer container): an newly created array of const strings, which must freed after use using g_free.
- */
-
-const char **
-arv_gc_enumeration_get_available_string_values (ArvGcEnumeration *enumeration, guint *n_values, GError **error)
+static const char **
+_get_available_string_values (ArvGcEnumeration *enumeration, gboolean display_name ,guint *n_values, GError **error)
 {
 	const char ** strings;
 	const GSList *entries, *iter;
@@ -361,14 +379,58 @@ arv_gc_enumeration_get_available_string_values (ArvGcEnumeration *enumeration, g
 	}
 
 	strings = g_new (const char*, *n_values);
-	for (iter = available_entries, i = 0; iter != NULL; iter = iter->next, i++)
-		strings[i] = arv_gc_feature_node_get_name (iter->data);
+	for (iter = available_entries, i = 0; iter != NULL; iter = iter->next, i++) {
+		const char *string = NULL;
+		if (display_name)
+			string = arv_gc_feature_node_get_display_name (iter->data, NULL);
+		if (string == NULL)
+			string = arv_gc_feature_node_get_name (iter->data);
+		strings[i] = string;
+	}
 
 	g_slist_free (available_entries);
 
 	return strings;
 }
 
+/**
+ * arv_gc_enumeration_get_available_string_values:
+ * @enumeration: an #ArvGcEnumeration
+ * @n_values: (out): placeholder for the number of values
+ * @error: placeholder for error, may be NULL
+ *
+ * Create an array of all available values of @enumeration, as strings.
+ *
+ * Returns: (array length=n_values) (transfer container): an newly created array of const strings, which must freed after use using g_free,
+ * %NULL on error.
+ */
+
+const char **
+arv_gc_enumeration_get_available_string_values (ArvGcEnumeration *enumeration, guint *n_values, GError **error)
+{
+	return _get_available_string_values (enumeration, FALSE, n_values, error);
+}
+
+/**
+ * arv_gc_enumeration_get_available_display_names:
+ * @enumeration: an #ArvGcEnumeration
+ * @n_values: (out): placeholder for the number of values
+ * @error: placeholder for error, may be NULL
+ *
+ * Create an array of display names of all available entries.
+ *
+ * Returns: (array length=n_values) (transfer container): an newly created array of const strings, which must freed after use using g_free,
+ * %NULL on error.
+ *
+ * Since: 0.8.0
+ */
+
+const char **
+arv_gc_enumeration_get_available_display_names (ArvGcEnumeration *enumeration, guint *n_values, GError **error)
+{
+	return _get_available_string_values (enumeration, TRUE, n_values, error);
+}
+
 void
 arv_gc_enumeration_set_int_value (ArvGcEnumeration *enumeration, gint64 value, GError **error)
 {
@@ -378,6 +440,40 @@ arv_gc_enumeration_set_int_value (ArvGcEnumeration *enumeration, gint64 value, G
 	if (enumeration->value) {
 		GError *local_error = NULL;
 
+		{
+			gint64 *available_values;
+			unsigned n_values;
+			unsigned i;
+			gboolean found = FALSE;
+
+			available_values = arv_gc_enumeration_get_available_int_values (enumeration, &n_values, &local_error);
+			if (local_error != NULL) {
+				g_propagate_error (error, local_error);
+				return;
+			}
+
+			if (available_values == NULL) {
+				g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_EMPTY_ENUMERATION,
+					     "No available entry found in <Enumeration> '%s'",
+					     arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (enumeration)));
+				return;
+			}
+
+			for (i = 0; i < n_values; i++)
+				if (available_values[i] == value)
+					found = TRUE;
+
+			g_free (available_values);
+
+			if (!found) {
+				g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_OUT_OF_RANGE,
+					     "Value not found in <Enumeration> '%s'",
+					     arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (enumeration)));
+				return;
+			}
+		}
+
+		arv_gc_feature_node_increment_change_count (ARV_GC_FEATURE_NODE (enumeration));
 		arv_gc_property_node_set_int64 (enumeration->value, value, &local_error);
 
 		if (local_error != NULL)
