@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2012 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,12 +31,11 @@
 #include <arvgcfeaturenode.h>
 #include <arvgcpropertynode.h>
 #include <arvgc.h>
+#include <arvgcenums.h>
 #include <arvmisc.h>
 #include <arvdebug.h>
 #include <string.h>
 
-static GObjectClass *parent_class = NULL;
-
 struct _ArvGcFeatureNodePrivate {
 
 	char *name;
@@ -49,7 +48,7 @@ struct _ArvGcFeatureNodePrivate {
 	ArvGcPropertyNode *is_available;
 	ArvGcPropertyNode *is_locked;
 
-	gint modification_count;
+	guint64 change_count;
 };
 
 /* ArvDomNode implementation */
@@ -314,16 +313,6 @@ arv_gc_feature_node_is_locked (ArvGcFeatureNode *gc_feature_node, GError **error
 	return value;
 }
 
-ArvGcFeatureNode *
-arv_gc_feature_node_new (void)
-{
-	ArvGcFeatureNode *node;
-
-	node = g_object_new (ARV_TYPE_GC_FEATURE_NODE, NULL);
-
-	return node;
-}
-
 GType
 arv_gc_feature_node_get_value_type (ArvGcFeatureNode *node)
 {
@@ -389,27 +378,29 @@ arv_gc_feature_node_get_value_as_string (ArvGcFeatureNode *gc_feature_node, GErr
 }
 
 void
-arv_gc_feature_node_inc_modification_count (ArvGcFeatureNode *gc_feature_node)
+arv_gc_feature_node_increment_change_count (ArvGcFeatureNode *gc_feature_node)
 {
 	g_return_if_fail (ARV_IS_GC_FEATURE_NODE (gc_feature_node));
 
-	gc_feature_node->priv->modification_count++;
+	gc_feature_node->priv->change_count++;
 }
 
-gint
-arv_gc_feature_node_get_modification_count (ArvGcFeatureNode *node)
+guint64
+arv_gc_feature_node_get_change_count (ArvGcFeatureNode *gc_feature_node)
 {
-	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), 0);
+	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (gc_feature_node), 0);
 
-	return node->priv->modification_count;
+	return gc_feature_node->priv->change_count;
 }
 
+G_DEFINE_ABSTRACT_TYPE_WITH_CODE (ArvGcFeatureNode, arv_gc_feature_node, ARV_TYPE_GC_NODE, G_ADD_PRIVATE (ArvGcFeatureNode))
+
 static void
 arv_gc_feature_node_init (ArvGcFeatureNode *gc_feature_node)
 {
-	gc_feature_node->priv = G_TYPE_INSTANCE_GET_PRIVATE (gc_feature_node, ARV_TYPE_GC_FEATURE_NODE, ArvGcFeatureNodePrivate);
+	gc_feature_node->priv = arv_gc_feature_node_get_instance_private (gc_feature_node);
 
-	gc_feature_node->priv->modification_count = 0;
+	gc_feature_node->priv->change_count = 0;
 }
 
 static void
@@ -419,7 +410,7 @@ arv_gc_feature_node_finalize (GObject *object)
 
 	g_free (node->priv->name);
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (arv_gc_feature_node_parent_class)->finalize (object);
 }
 
 static void
@@ -429,12 +420,6 @@ arv_gc_feature_node_class_init (ArvGcFeatureNodeClass *this_class)
 	ArvDomNodeClass *dom_node_class = ARV_DOM_NODE_CLASS (this_class);
 	ArvDomElementClass *dom_element_class = ARV_DOM_ELEMENT_CLASS (this_class);
 
-#if !GLIB_CHECK_VERSION(2,38,0)
-	g_type_class_add_private (this_class, sizeof (ArvGcFeatureNodePrivate));
-#endif
-
-	parent_class = g_type_class_peek_parent (this_class);
-
 	object_class->finalize = arv_gc_feature_node_finalize;
 	dom_node_class->can_append_child = arv_gc_feature_node_can_append_child;
 	dom_node_class->post_new_child = arv_gc_feature_node_post_new_child;
@@ -443,9 +428,3 @@ arv_gc_feature_node_class_init (ArvGcFeatureNodeClass *this_class)
 	dom_element_class->get_attribute = arv_gc_feature_node_get_attribute;
 	this_class->get_value_type = NULL;
 }
-
-#if !GLIB_CHECK_VERSION(2,38,0)
-G_DEFINE_TYPE (ArvGcFeatureNode, arv_gc_feature_node, ARV_TYPE_GC_NODE)
-#else
-G_DEFINE_TYPE_WITH_CODE (ArvGcFeatureNode, arv_gc_feature_node, ARV_TYPE_GC_NODE, G_ADD_PRIVATE (ArvGcFeatureNode))
-#endif
