@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2012 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,10 @@
 #ifndef ARV_GC_FEATURE_NODE_H
 #define ARV_GC_FEATURE_NODE_H
 
+#if !defined (ARV_H_INSIDE) && !defined (ARAVIS_COMPILATION)
+#error "Only <arv.h> can be included directly."
+#endif
+
 #include <arvtypes.h>
 #include <arvgcnode.h>
 
@@ -55,8 +59,6 @@ struct _ArvGcFeatureNodeClass {
 
 GType 			arv_gc_feature_node_get_type 			(void);
 
-ArvGcFeatureNode * 	arv_gc_feature_node_new 			(void);
-
 const char *		arv_gc_feature_node_get_name			(ArvGcFeatureNode *gc_feature_node);
 
 const char *		arv_gc_feature_node_get_tooltip			(ArvGcFeatureNode *gc_feature_node, GError **error);
@@ -72,9 +74,6 @@ const char *		arv_gc_feature_node_get_value_as_string		(ArvGcFeatureNode *gc_fea
 
 GType 			arv_gc_feature_node_get_value_type 		(ArvGcFeatureNode *gc_feature_node);
 
-void 			arv_gc_feature_node_inc_modification_count 	(ArvGcFeatureNode *gc_feature_node);
-gint 			arv_gc_feature_node_get_modification_count 	(ArvGcFeatureNode *gc_feature_node);
-
 G_END_DECLS
 
 #endif
