@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2012 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,10 @@
 #ifndef ARV_GC_INVALIDATOR_NODE_H
 #define ARV_GC_INVALIDATOR_NODE_H
 
+#if !defined (ARV_H_INSIDE) && !defined (ARAVIS_COMPILATION)
+#error "Only <arv.h> can be included directly."
+#endif
+
 #include <arvtypes.h>
 #include <arvgcpropertynode.h>
 
@@ -40,7 +44,7 @@ typedef struct _ArvGcInvalidatorNodeClass ArvGcInvalidatorNodeClass;
 struct _ArvGcInvalidatorNode {
 	ArvGcPropertyNode	base;
 
-	gint modification_count;
+	guint64 change_index;
 };
 
 struct _ArvGcInvalidatorNodeClass {
@@ -49,8 +53,8 @@ struct _ArvGcInvalidatorNodeClass {
 
 GType 		arv_gc_invalidator_node_get_type 		(void);
 ArvGcNode * 	arv_gc_invalidator_node_new 			(void);
-gint		arv_gc_invalidator_node_get_modification_count	(ArvGcInvalidatorNode *invalidator_node);
-void		arv_gc_invalidator_node_set_modification_count	(ArvGcInvalidatorNode *invalidator_node, gint modification_count);
+
+gboolean 	arv_gc_invalidator_has_changed 			(ArvGcInvalidatorNode *self);
 
 G_END_DECLS
 
