@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2012 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -41,7 +41,9 @@ typedef enum {
 	ARV_GC_PROPERTY_NODE_TYPE_DISPLAY_NAME,
 	ARV_GC_PROPERTY_NODE_TYPE_MINIMUM,
 	ARV_GC_PROPERTY_NODE_TYPE_MAXIMUM,
+	ARV_GC_PROPERTY_NODE_TYPE_SLOPE,
 	ARV_GC_PROPERTY_NODE_TYPE_INCREMENT,
+	ARV_GC_PROPERTY_NODE_TYPE_IS_LINEAR,
 	ARV_GC_PROPERTY_NODE_TYPE_UNIT,
 	ARV_GC_PROPERTY_NODE_TYPE_ON_VALUE,
 	ARV_GC_PROPERTY_NODE_TYPE_OFF_VALUE,
@@ -61,6 +63,8 @@ typedef enum {
 	ARV_GC_PROPERTY_NODE_TYPE_BIT,
 	ARV_GC_PROPERTY_NODE_TYPE_COMMAND_VALUE,
 	ARV_GC_PROPERTY_NODE_TYPE_CHUNK_ID,
+	ARV_GC_PROPERTY_NODE_TYPE_VALUE_INDEXED,
+	ARV_GC_PROPERTY_NODE_TYPE_VALUE_DEFAULT,
 
 	ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW	= 1000,
 	ARV_GC_PROPERTY_NODE_TYPE_P_FEATURE,
@@ -77,7 +81,9 @@ typedef enum {
 	ARV_GC_PROPERTY_NODE_TYPE_P_PORT,
 	ARV_GC_PROPERTY_NODE_TYPE_P_VARIABLE,
 	ARV_GC_PROPERTY_NODE_TYPE_P_INVALIDATOR,
-	ARV_GC_PROPERTY_NODE_TYPE_P_COMMAND_VALUE
+	ARV_GC_PROPERTY_NODE_TYPE_P_COMMAND_VALUE,
+	ARV_GC_PROPERTY_NODE_TYPE_P_VALUE_INDEXED,
+	ARV_GC_PROPERTY_NODE_TYPE_P_VALUE_DEFAULT
 } ArvGcPropertyNodeType;
 
 #define ARV_TYPE_GC_PROPERTY_NODE             (arv_gc_property_node_get_type ())
@@ -119,8 +125,10 @@ ArvGcNode * 	arv_gc_property_node_new_minimum		(void);
 ArvGcNode * 	arv_gc_property_node_new_p_minimum		(void);
 ArvGcNode * 	arv_gc_property_node_new_maximum		(void);
 ArvGcNode * 	arv_gc_property_node_new_p_maximum		(void);
+ArvGcNode * 	arv_gc_property_node_new_slope			(void);
 ArvGcNode * 	arv_gc_property_node_new_increment		(void);
 ArvGcNode * 	arv_gc_property_node_new_p_increment		(void);
+ArvGcNode * 	arv_gc_property_node_new_is_linear		(void);
 ArvGcNode * 	arv_gc_property_node_new_unit			(void);
 ArvGcNode * 	arv_gc_property_node_new_on_value 		(void);
 ArvGcNode * 	arv_gc_property_node_new_off_value 		(void);
@@ -147,6 +155,8 @@ ArvGcNode * 	arv_gc_property_node_new_bit			(void);
 ArvGcNode * 	arv_gc_property_node_new_command_value		(void);
 ArvGcNode * 	arv_gc_property_node_new_p_command_value	(void);
 ArvGcNode * 	arv_gc_property_node_new_chunk_id 		(void);
+ArvGcNode * 	arv_gc_property_node_new_value_default 		(void);
+ArvGcNode * 	arv_gc_property_node_new_p_value_default	(void);
 
 const char *		arv_gc_property_node_get_name		(ArvGcPropertyNode *node);
 
