@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2010 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,14 +20,16 @@
  * Author: Emmanuel Pacaud <emmanuel@gnome.org>
  */
 
-/**
+/*
  * SECTION: arvgvsp
  * @short_description: GigEVision stream packet handling
  */
 
-#include <arvgvsp.h>
 #include <arvdebug.h>
+#include <arvmisc.h>
 #include <arvenumtypes.h>
+#include <arvgvspprivate.h>
+#include <arvenumtypesprivate.h>
 #include <string.h>
 
 static ArvGvspPacket *
@@ -74,7 +76,8 @@ arv_gvsp_packet_new_data_leader	(guint16 frame_id, guint32 packet_id,
 		ArvGvspDataLeader *leader;
 
 		leader = (ArvGvspDataLeader *) &packet->data;
-		leader->payload_type = g_htonl (0x00000001); /* ID for image data */
+		leader->flags = 0;
+		leader->payload_type = g_htons (ARV_GVSP_PAYLOAD_TYPE_IMAGE);
 		leader->timestamp_high = g_htonl (((guint64) timestamp >> 32));
 		leader->timestamp_low  = g_htonl ((guint64) timestamp & 0xffffffff);
 		leader->pixel_format = g_htonl (pixel_format);
@@ -100,8 +103,8 @@ arv_gvsp_packet_new_data_trailer (guint16 frame_id, guint32 packet_id,
 		ArvGvspDataTrailer *trailer;
 
 		trailer = (ArvGvspDataTrailer *) &packet->data;
+		trailer->payload_type = g_htonl (ARV_GVSP_PAYLOAD_TYPE_IMAGE);
 		trailer->data0 = 0;
-		trailer->data1 = 0;
 	}
 
 	return packet;
@@ -162,21 +165,41 @@ arv_gvsp_packet_to_string (const ArvGvspPacket *packet, size_t packet_size)
 	ArvGvspContentType content_type;
 	GString *string;
 	char *c_string;
-	int i, j, index;
 
 	string = g_string_new ("");
 
 	packet_type = arv_gvsp_packet_get_packet_type (packet);
 	content_type = arv_gvsp_packet_get_content_type (packet);
 
-	g_string_append_printf (string, "packet_type  = %s (%04x)\n", arv_gvsp_packet_type_to_string (packet_type), packet_type);
-	g_string_append_printf (string, "content_type = %s (%04x)\n", arv_gvsp_content_type_to_string (content_type), content_type);
+	g_string_append_printf (string, "packet_type  = %8s (0x%04x)\n", arv_gvsp_packet_type_to_string (packet_type), packet_type);
+	g_string_append_printf (string, "content_type = %8s (0x%04x)\n", arv_gvsp_content_type_to_string (content_type), content_type);
 
 	switch (content_type) {
 		case ARV_GVSP_CONTENT_TYPE_DATA_LEADER:
 			leader = (ArvGvspDataLeader *) &packet->data;
+			switch (g_ntohl (leader->payload_type)) {
+				case ARV_GVSP_PAYLOAD_TYPE_IMAGE:
+					g_string_append (string, "payload_type = image\n");
+					break;
+				case ARV_GVSP_PAYLOAD_TYPE_CHUNK_DATA:
+					g_string_append (string, "payload_type = chunk\n");
+					break;
+				case ARV_GVSP_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA:
+					g_string_append (string, "payload_type = extended chunk\n");
+					break;
+				case ARV_GVSP_PAYLOAD_TYPE_H264:
+					g_string_append (string, "payload_type = h264\n");
+					break;
+				default:
+					g_string_append (string, "payload_type = unknown\n");
+					break;
+			}
+			g_string_append_printf (string, "pixel format = %s\n",
+						arv_pixel_format_to_gst_caps_string (g_ntohl (leader->pixel_format)));
 			g_string_append_printf (string, "width        = %d\n", g_ntohl (leader->width));
 			g_string_append_printf (string, "height       = %d\n", g_ntohl (leader->height));
+			g_string_append_printf (string, "x_offset     = %d\n", g_ntohl (leader->x_offset));
+			g_string_append_printf (string, "y_offset     = %d\n", g_ntohl (leader->y_offset));
 			break;
 		case ARV_GVSP_CONTENT_TYPE_DATA_TRAILER:
 			break;
@@ -184,32 +207,6 @@ arv_gvsp_packet_to_string (const ArvGvspPacket *packet, size_t packet_size)
 			break;
 	}
 
-	for (i = 0; i < (packet_size + 15) / 16; i++) {
-		for (j = 0; j < 16; j++) {
-			index = i * 16 + j;
-			if (j == 0)
-				g_string_append_printf (string, "%04x", i * 16);
-			if (index < packet_size)
-				g_string_append_printf (string, " %02x", *((guint8 *) ((void *) packet) + index));
-			else
-				g_string_append (string, "   ");
-		}
-		for (j = 0; j < 16; j++) {
-			index = i * 16 + j;
-			if (j == 0)
-				g_string_append (string, "  ");
-			if (index < packet_size)
-				if (*((char *) ((void *) packet) + index) >= ' ' &&
-				    *((char *) ((void *) packet) + index) <  '\x7f')
-					g_string_append_c (string, *((char *) ((void *) packet) + index));
-				else g_string_append_c (string, '.');
-			else
-				g_string_append_c (string, ' ');
-		}
-		if (index < packet_size)
-			g_string_append (string, "\n");
-	}
-
 	c_string = string->str;
 
 	g_string_free (string, FALSE);
