@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2016 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,9 +29,9 @@
 #include <arvgvdeviceprivate.h>
 #include <arvstreamprivate.h>
 #include <arvbufferprivate.h>
-#include <arvconfig.h>
-#include <arvgvsp.h>
-#include <arvgvcp.h>
+#include <arvfeatures.h>
+#include <arvgvspprivate.h>
+#include <arvgvcpprivate.h>
 #include <arvdebug.h>
 #include <arvmisc.h>
 #include <arvstr.h>
@@ -42,7 +42,7 @@
 #include <errno.h>
 #include <arvwakeupprivate.h>
 
-#ifdef ARAVIS_BUILD_PACKET_SOCKET
+#if ARAVIS_HAS_PACKET_SOCKET
 #include <ifaddrs.h>
 #include <netinet/udp.h>
 #include <net/if.h>
@@ -74,8 +74,6 @@ enum {
 	ARV_GV_STREAM_PROPERTY_FRAME_RETENTION
 } ArvGvStreamProperties;
 
-static GObjectClass *parent_class = NULL;
-
 typedef struct _ArvGvStreamThreadData ArvGvStreamThreadData;
 
 struct _ArvGvStreamPrivate {
@@ -506,7 +504,6 @@ _missing_packet_check (ArvGvStreamThreadData *thread_data,
 static void
 _close_frame (ArvGvStreamThreadData *thread_data, ArvGvStreamFrameData *frame)
 {
-	GTimeVal current_time;
 	gint64 current_time_us;
 
 	if (frame->buffer->priv->status == ARV_BUFFER_STATUS_SUCCESS)
@@ -531,8 +528,7 @@ _close_frame (ArvGvStreamThreadData *thread_data, ArvGvStreamFrameData *frame)
 				       ARV_STREAM_CALLBACK_TYPE_BUFFER_DONE,
 				       frame->buffer);
 
-	g_get_current_time (&current_time);
-	current_time_us = current_time.tv_sec * 1000000 + current_time.tv_usec;
+	current_time_us = g_get_monotonic_time ();
 	if (thread_data->statistic_count > 5) {
 		arv_statistic_fill (thread_data->statistic, 0,
 				    current_time_us - frame->first_packet_time_us,
@@ -723,7 +719,6 @@ _loop (ArvGvStreamThreadData *thread_data)
 	ArvGvStreamFrameData *frame;
 	ArvGvspPacket *packet;
 	GPollFD poll_fd[2];
-	GTimeVal current_time;
 	guint64 time_us;
 	size_t read_count;
 	int timeout_ms;
@@ -755,8 +750,7 @@ _loop (ArvGvStreamThreadData *thread_data)
 
 		} while (n_events < 0 && errsv == EINTR);
 
-		g_get_current_time (&current_time);
-		time_us = current_time.tv_sec * 1000000 + current_time.tv_usec;
+		time_us = g_get_monotonic_time ();
 
 		if (poll_fd[0].revents != 0) {
 			read_count = g_socket_receive (thread_data->socket, (char *) packet,
@@ -774,7 +768,7 @@ _loop (ArvGvStreamThreadData *thread_data)
 }
 
 
-#ifdef ARAVIS_BUILD_PACKET_SOCKET
+#if ARAVIS_HAS_PACKET_SOCKET
 
 static void
 _set_socket_filter (int socket, guint32 source_ip, guint32 source_port, guint32 destination_ip, guint32 destination_port)
@@ -916,11 +910,9 @@ _ring_buffer_loop (ArvGvStreamThreadData *thread_data)
 	block_id = 0;
 	do {
 		ArvGvStreamBlockDescriptor *descriptor;
-		GTimeVal current_time;
 		guint64 time_us;
 
-		g_get_current_time (&current_time);
-		time_us = current_time.tv_sec * 1000000 + current_time.tv_usec;
+		time_us = g_get_monotonic_time ();
 
 		descriptor = (void *) (buffer + block_id * req.tp_block_size);
 		if ((descriptor->h1.block_status & TP_STATUS_USER) == 0) {
@@ -968,13 +960,13 @@ map_error:
 	close (fd);
 }
 
-#endif /* ARAVIS_BUILD_PACKET_SOCKET */
+#endif /* ARAVIS_HAS_PACKET_SOCKET */
 
 static void *
 arv_gv_stream_thread (void *data)
 {
 	ArvGvStreamThreadData *thread_data = data;
-#ifdef ARAVIS_BUILD_PACKET_SOCKET
+#if ARAVIS_HAS_PACKET_SOCKET
 	int fd;
 #endif
 
@@ -990,7 +982,7 @@ arv_gv_stream_thread (void *data)
 	if (thread_data->callback != NULL)
 		thread_data->callback (thread_data->user_data, ARV_STREAM_CALLBACK_TYPE_INIT, NULL);
 
-#ifdef ARAVIS_BUILD_PACKET_SOCKET
+#if ARAVIS_HAS_PACKET_SOCKET
 	if (thread_data->use_packet_socket && (fd = socket (PF_PACKET, SOCK_RAW, g_htons (ETH_P_ALL))) >= 0) {
 		close (fd);
 		_ring_buffer_loop (thread_data);
@@ -1155,9 +1147,9 @@ arv_gv_stream_new (ArvGvDevice *gv_device,
 	g_object_unref (local_address);
 
 	address_bytes = g_inet_address_to_bytes (interface_address);
-	arv_device_set_integer_feature_value (ARV_DEVICE (gv_device), "GevSCDA", g_htonl (*((guint32 *) address_bytes)));
-	arv_device_set_integer_feature_value (ARV_DEVICE (gv_device), "GevSCPHostPort", thread_data->stream_port);
-	thread_data->source_stream_port = arv_device_get_integer_feature_value (ARV_DEVICE (gv_device), "GevSCSP");
+	arv_device_set_integer_feature_value (ARV_DEVICE (gv_device), "GevSCDA", g_htonl (*((guint32 *) address_bytes)), NULL);
+	arv_device_set_integer_feature_value (ARV_DEVICE (gv_device), "GevSCPHostPort", thread_data->stream_port, NULL);
+	thread_data->source_stream_port = arv_device_get_integer_feature_value (ARV_DEVICE (gv_device), "GevSCSP", NULL);
 
 	thread_data->wakeup = arv_wakeup_new();
 
@@ -1273,10 +1265,12 @@ arv_gv_stream_get_property (GObject * object, guint prop_id,
 	}
 }
 
+G_DEFINE_TYPE_WITH_CODE (ArvGvStream, arv_gv_stream, ARV_TYPE_STREAM, G_ADD_PRIVATE (ArvGvStream))
+
 static void
 arv_gv_stream_init (ArvGvStream *gv_stream)
 {
-	gv_stream->priv = G_TYPE_INSTANCE_GET_PRIVATE (gv_stream, ARV_TYPE_GV_STREAM, ArvGvStreamPrivate);
+	gv_stream->priv = arv_gv_stream_get_instance_private (gv_stream);
 }
 
 static void
@@ -1340,7 +1334,7 @@ arv_gv_stream_finalize (GObject *object)
 		g_clear_pointer (&thread_data, g_free);
 	}
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (arv_gv_stream_parent_class)->finalize (object);
 }
 
 static void
@@ -1349,12 +1343,6 @@ arv_gv_stream_class_init (ArvGvStreamClass *gv_stream_class)
 	GObjectClass *object_class = G_OBJECT_CLASS (gv_stream_class);
 	ArvStreamClass *stream_class = ARV_STREAM_CLASS (gv_stream_class);
 
-#if !GLIB_CHECK_VERSION(2,38,0)
-	g_type_class_add_private (gv_stream_class, sizeof (ArvGvStreamPrivate));
-#endif
-
-	parent_class = g_type_class_peek_parent (gv_stream_class);
-
 	object_class->finalize = arv_gv_stream_finalize;
 	object_class->set_property = arv_gv_stream_set_property;
 	object_class->get_property = arv_gv_stream_get_property;
@@ -1412,9 +1400,3 @@ arv_gv_stream_class_init (ArvGvStreamClass *gv_stream_class)
 				   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)
 		);
 }
-
-#if !GLIB_CHECK_VERSION(2,38,0)
-G_DEFINE_TYPE (ArvGvStream, arv_gv_stream, ARV_TYPE_STREAM)
-#else
-G_DEFINE_TYPE_WITH_CODE (ArvGvStream, arv_gv_stream, ARV_TYPE_STREAM, G_ADD_PRIVATE (ArvGvStream))
-#endif
