@@ -1,3 +1,25 @@
+/* Aravis - Digital camera library
+ *
+ * Copyright © 2009-2019 Emmanuel Pacaud
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ *
+ * Author: Emmanuel Pacaud <emmanuel@gnome.org>
+ */
+
 #include <arv.h>
 #include <stdlib.h>
 #include <string.h>
@@ -58,20 +80,13 @@ arv_tool_list_features (ArvGc *genicam, const char *feature, gboolean show_descr
 }
 
 static void
-arv_tool_execute_command (int argc, char **argv, const char *device_name)
+arv_tool_execute_command (int argc, char **argv, ArvDevice *device)
 {
-	ArvDevice *device;
 	ArvGc *genicam;
 	const char *command = argv[1];
 
-	device = arv_open_device (device_name);
-	if (!ARV_IS_DEVICE (device)) {
-		if (device_name != NULL)
-			printf ("Device '%s' not found\n", device_name);
-		else
-			printf ("No device found\n");
+	if (device == NULL || argc < 2)
 		return;
-	}
 
 	genicam = arv_device_get_genicam (device);
 
@@ -120,8 +135,6 @@ arv_tool_execute_command (int argc, char **argv, const char *device_name)
 					printf ("%s executed\n", tokens[0]);
 				} else {
 					GType value_type;
-					gint64 max_int64, min_int64;
-					double max_double, min_double;
 					const char *unit;
 
 					if (tokens[1] != NULL)
@@ -132,42 +145,63 @@ arv_tool_execute_command (int argc, char **argv, const char *device_name)
 
 					switch (value_type) {
 						case G_TYPE_INT64:
-							min_int64 = arv_gc_integer_get_min (ARV_GC_INTEGER (feature), NULL);
-							max_int64 = arv_gc_integer_get_max (ARV_GC_INTEGER (feature), NULL);
-							unit = arv_gc_integer_get_unit (ARV_GC_INTEGER (feature), NULL);
+							if (ARV_IS_GC_ENUMERATION (feature)) {
+								printf ("%s = %s\n", tokens[0],
+									arv_gc_string_get_value (ARV_GC_STRING (feature), NULL));
+							} else {
+								gint64 max_int64, min_int64, inc_int64;
+								GString *string = g_string_new ("");
 
-							if (min_int64 != -G_MAXINT64 && max_int64 != G_MAXINT64)
-								printf ("%s = %" G_GINT64_FORMAT
-									"%s%s (min:%" G_GINT64_FORMAT
-									";max:%" G_GINT64_FORMAT
-									")\n", tokens[0],
-									arv_gc_integer_get_value (ARV_GC_INTEGER (feature), NULL),
-									unit != NULL ? " ": "",
-									unit != NULL ? unit : "",
-									min_int64, max_int64);
-							else
-								printf ("%s = %" G_GINT64_FORMAT "%s%s\n",
-									tokens[0],
-									arv_gc_integer_get_value (ARV_GC_INTEGER (feature), NULL),
-									unit != NULL ? " ": "",
-									unit != NULL ? unit : "");
+								min_int64 = arv_gc_integer_get_min (ARV_GC_INTEGER (feature), NULL);
+								max_int64 = arv_gc_integer_get_max (ARV_GC_INTEGER (feature), NULL);
+								inc_int64 = arv_gc_integer_get_inc (ARV_GC_INTEGER (feature), NULL);
+								unit = arv_gc_integer_get_unit (ARV_GC_INTEGER (feature), NULL);
+
+								g_string_append_printf (string, "%s = %" G_GINT64_FORMAT,
+											tokens[0],
+											arv_gc_integer_get_value (ARV_GC_INTEGER (feature),
+														  NULL));
+
+								if (unit != NULL)
+									g_string_append_printf (string, " %s", unit);
+								if (min_int64 != G_MININT64)
+									g_string_append_printf (string, " min:%" G_GINT64_FORMAT, min_int64);
+								if (max_int64 != G_MAXINT64)
+									g_string_append_printf (string, " max:%" G_GINT64_FORMAT, max_int64);
+								if (inc_int64 != 1)
+									g_string_append_printf (string, " inc:%" G_GINT64_FORMAT, inc_int64);
+
+								printf ("%s\n", string->str);
+								g_string_free (string, TRUE);
+							}
 							break;
 						case G_TYPE_DOUBLE:
-							min_double = arv_gc_float_get_min (ARV_GC_FLOAT (feature), NULL);
-							max_double = arv_gc_float_get_max (ARV_GC_FLOAT (feature), NULL);
-							unit = arv_gc_float_get_unit (ARV_GC_FLOAT (feature), NULL);
+							{
+								double max_double, min_double, inc_double;
+								GString *string = g_string_new ("");
 
-							if (min_double != -G_MAXDOUBLE && max_double != G_MAXDOUBLE)
-								printf ("%s = %g%s%s (min:%g;max:%g)\n", tokens[0],
-									arv_gc_float_get_value (ARV_GC_FLOAT (feature), NULL),
-									unit != NULL ? " ": "",
-									unit != NULL ? unit : "",
-									min_double, max_double);
-							else
-								printf ("%s = %g%s%s\n", tokens[0],
-									arv_gc_float_get_value (ARV_GC_FLOAT (feature), NULL),
-									unit != NULL ? " ": "",
-									unit != NULL ? unit : "");
+								min_double = arv_gc_float_get_min (ARV_GC_FLOAT (feature), NULL);
+								max_double = arv_gc_float_get_max (ARV_GC_FLOAT (feature), NULL);
+								inc_double = arv_gc_float_get_inc (ARV_GC_FLOAT (feature), NULL);
+								unit = arv_gc_float_get_unit (ARV_GC_FLOAT (feature), NULL);
+
+								g_string_append_printf (string, "%s = %g",
+											tokens[0],
+											arv_gc_float_get_value (ARV_GC_FLOAT (feature),
+														NULL));
+
+								if (unit != NULL)
+									g_string_append_printf (string, " %s", unit);
+								if (min_double != -G_MAXDOUBLE)
+									g_string_append_printf (string, " min:%g", min_double);
+								if (max_double != G_MAXDOUBLE)
+									g_string_append_printf (string, " max:%g", max_double);
+								if (inc_double != 1)
+									g_string_append_printf (string, " inc:%g", inc_double);
+
+								printf ("%s\n", string->str);
+								g_string_free (string, TRUE);
+							}
 							break;
 						case G_TYPE_STRING:
 							printf ("%s = %s\n", tokens[0],
@@ -211,8 +245,6 @@ arv_tool_execute_command (int argc, char **argv, const char *device_name)
 	} else {
 		printf ("Unkown command\n");
 	}
-
-	g_object_unref (device);
 }
 
 static char *arv_option_device_name = NULL;
@@ -223,7 +255,7 @@ static const GOptionEntry arv_option_entries[] =
 {
 	{ "name",		'n', 0, G_OPTION_ARG_STRING,
 		&arv_option_device_name,	NULL, "<device_name>"},
-	{ "address",	'a', 0, G_OPTION_ARG_STRING,
+	{ "address",		'a', 0, G_OPTION_ARG_STRING,
 		&arv_option_device_address,	NULL, "<device_address>"},
 	{ "debug", 		'd', 0, G_OPTION_ARG_STRING,
 		&arv_option_debug_domains, 	NULL, "<category>[:<level>][,...]" },
@@ -253,15 +285,12 @@ description_content[] =
 int
 main (int argc, char **argv)
 {
-	GPatternSpec *pattern;
+	ArvDevice *device;
+	const char *device_id;
 	GOptionContext *context;
 	GError *error = NULL;
 	unsigned int n_devices;
 	unsigned int i;
-	unsigned int count = 0;
-
-	arv_g_thread_init (NULL);
-	arv_g_type_init ();
 
 	context = g_option_context_new (" command <parameters>");
 	g_option_context_set_summary (context, "Small utility for basic control of a Genicam device.");
@@ -279,33 +308,40 @@ main (int argc, char **argv)
 
 	arv_debug_enable (arv_option_debug_domains);
 
-	arv_update_device_list ();
-	n_devices = arv_get_n_devices ();
+	device_id = arv_option_device_address != NULL ? arv_option_device_address : arv_option_device_name;
+	if (device_id != NULL) {
+		device = arv_open_device (device_id);
 
-	if (arv_option_device_address != NULL)
-		pattern = g_pattern_spec_new (arv_option_device_address);
-	else if (arv_option_device_name != NULL)
-		pattern = g_pattern_spec_new (arv_option_device_name);
-	else
-		pattern = g_pattern_spec_new ("*");
+		if (ARV_IS_DEVICE (device)) {
+			if (argc < 2)
+				printf ("%s\n", device_id);
+			else
+				arv_tool_execute_command (argc, argv, device);
+			g_object_unref (device);
+		} else {
+			fprintf (stderr, "Device '%s' not found\n", device_id);
+		}
+	} else {
+		arv_update_device_list ();
+		n_devices = arv_get_n_devices ();
 
-	for (i = 0; i < n_devices; i++) {
-		const char *device_id = arv_get_device_id (i);
-		const char *ip_address = arv_get_device_address (i);
+		if (n_devices > 0) {
+			for (i = 0; i < n_devices; i++) {
+				device_id = arv_get_device_id (i);
+				device = arv_open_device (device_id);
 
-		if (g_pattern_match_string (pattern, arv_option_device_address != NULL ? ip_address : device_id)) {
-			printf ("%s (%s)\n", device_id, ip_address);
-			if (argc >= 2)
-				arv_tool_execute_command (argc, argv, device_id);
-			count++;
+				if (ARV_IS_DEVICE (device)) {
+					printf ("%s (%s)\n", device_id, arv_get_device_address (i));
+					arv_tool_execute_command (argc, argv, device);
+
+					g_object_unref (device);
+				}
+			}
+		} else {
+			fprintf (stderr, "No device found\n");
 		}
 	}
 
-	if (count == 0)
-		printf ("No device found\n");
-
-	g_pattern_spec_free (pattern);
-
 	arv_shutdown ();
 
 	return EXIT_SUCCESS;
