@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2016 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -50,6 +50,7 @@ typedef struct _ArvGc ArvGc;
 typedef	struct _ArvGcNode			ArvGcNode;
 typedef struct _ArvGcPropertyNode		ArvGcPropertyNode;
 typedef struct _ArvGcIndexNode			ArvGcIndexNode;
+typedef struct _ArvGcValueIndexedNode		ArvGcValueIndexedNode;
 typedef struct _ArvGcInvalidatorNode		ArvGcInvalidatorNode;
 typedef struct _ArvGcFeatureNode 		ArvGcFeatureNode;
 typedef struct _ArvGcRegisterDescriptionNode 	ArvGcRegisterDescriptionNode;
@@ -65,6 +66,8 @@ typedef struct _ArvGcStructEntryNode		ArvGcStructEntryNode;
 typedef struct _ArvGcCommand			ArvGcCommand;
 typedef struct _ArvGcSwissKnife			ArvGcSwissKnife;
 typedef struct _ArvGcConverter			ArvGcConverter;
+typedef struct _ArvGcConverterNode		ArvGcConverterNode;
+typedef struct _ArvGcIntConverterNode		ArvGcIntConverterNode;
 typedef struct _ArvGcPort			ArvGcPort;
 
 typedef struct _ArvGcRegister		ArvGcRegister;
