@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2016 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,8 +28,8 @@
 #include <arvuvstreamprivate.h>
 #include <arvstreamprivate.h>
 #include <arvbufferprivate.h>
-#include <arvuvsp.h>
-#include <arvuvcp.h>
+#include <arvuvspprivate.h>
+#include <arvuvcpprivate.h>
 #include <arvdebug.h>
 #include <arvmisc.h>
 #include <libusb.h>
@@ -37,8 +37,6 @@
 
 #define ARV_UV_STREAM_MAXIMUM_TRANSFER_SIZE	1048576
 
-static GObjectClass *parent_class = NULL;
-
 /* Acquisition thread */
 
 typedef struct {
@@ -103,7 +101,7 @@ arv_uv_stream_thread (void *data)
 		if (buffer != NULL &&
 		    buffer->priv->status == ARV_BUFFER_STATUS_FILLING &&
 		    offset + size <= buffer->priv->size)
-			packet = buffer->priv->data + offset;
+			packet = (ArvUvspPacket *) (buffer->priv->data + offset);
 		else
 			packet = incoming_buffer;
 
@@ -412,10 +410,12 @@ arv_uv_stream_get_statistics (ArvStream *stream,
 	*n_underruns = thread_data->n_underruns;
 }
 
+G_DEFINE_TYPE_WITH_CODE (ArvUvStream, arv_uv_stream, ARV_TYPE_STREAM, G_ADD_PRIVATE (ArvUvStream))
+
 static void
 arv_uv_stream_init (ArvUvStream *uv_stream)
 {
-	uv_stream->priv = G_TYPE_INSTANCE_GET_PRIVATE (uv_stream, ARV_TYPE_UV_STREAM, ArvUvStreamPrivate);
+	uv_stream->priv = arv_uv_stream_get_instance_private (uv_stream);
 }
 
 static void
@@ -441,7 +441,7 @@ arv_uv_stream_finalize (GObject *object)
 		g_clear_pointer (&uv_stream->priv->thread_data, g_free);
 	}
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (arv_uv_stream_parent_class)->finalize (object);
 }
 
 static void
@@ -450,21 +450,9 @@ arv_uv_stream_class_init (ArvUvStreamClass *uv_stream_class)
 	GObjectClass *object_class = G_OBJECT_CLASS (uv_stream_class);
 	ArvStreamClass *stream_class = ARV_STREAM_CLASS (uv_stream_class);
 
-#if !GLIB_CHECK_VERSION(2,38,0)
-	g_type_class_add_private (uv_stream_class, sizeof (ArvUvStreamPrivate));
-#endif
-
-	parent_class = g_type_class_peek_parent (uv_stream_class);
-
 	object_class->finalize = arv_uv_stream_finalize;
 
 	stream_class->start_thread = arv_uv_stream_start_thread;
 	stream_class->stop_thread = arv_uv_stream_stop_thread;
 	stream_class->get_statistics = arv_uv_stream_get_statistics;
 }
-
-#if !GLIB_CHECK_VERSION(2,38,0)
-G_DEFINE_TYPE (ArvUvStream, arv_uv_stream, ARV_TYPE_STREAM)
-#else
-G_DEFINE_TYPE_WITH_CODE (ArvUvStream, arv_uv_stream, ARV_TYPE_STREAM, G_ADD_PRIVATE (ArvUvStream))
-#endif
