@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2016 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,11 +24,16 @@
 #include <gst/gst.h>
 #include <gst/app/gstappsrc.h>
 #include <gst/video/videooverlay.h>
-#include <gdk/gdkx.h>
 #include <arv.h>
 #include <math.h>
 #include <memory.h>
 #include <libnotify/notify.h>
+#ifdef GDK_WINDOWING_X11
+#include <gdk/gdkx.h>  // for GDK_WINDOW_XID
+#endif
+#ifdef GDK_WINDOWING_WIN32
+#include <gdk/gdkwin32.h>  // for GDK_WINDOW_HWND
+#endif
 
 static gboolean has_autovideo_sink = FALSE;
 static gboolean has_gtksink = FALSE;
@@ -147,7 +152,10 @@ typedef struct {
 	GtkWidget *camera_binning_y;
 	GtkWidget *camera_width;
 	GtkWidget *camera_height;
+	GtkWidget *video_box;
 	GtkWidget *video_frame;
+	GtkWidget *fps_label;
+	GtkWidget *image_label;
 	GtkWidget *trigger_combo_box;
 	GtkWidget *frame_rate_entry;
 	GtkWidget *exposure_spin_button;
@@ -176,10 +184,19 @@ typedef struct {
 	guint gain_update_event;
 	guint exposure_update_event;
 
+	guint status_bar_update_event;
+	gint64 last_status_bar_update_time_ms;
+	unsigned last_n_images;
+	unsigned last_n_bytes;
+	unsigned n_images;
+	unsigned n_bytes;
+	unsigned n_errors;
+
 	gboolean auto_socket_buffer;
 	gboolean packet_resend;
 	guint packet_timeout;
 	guint frame_retention;
+	ArvRegisterCachePolicy cache_policy;
 
 	gulong video_window_xid;
 } ArvViewer;
@@ -200,7 +217,8 @@ arv_viewer_set_options (ArvViewer *viewer,
 			gboolean auto_socket_buffer,
 			gboolean packet_resend,
 			guint packet_timeout,
-			guint frame_retention)
+			guint frame_retention,
+			ArvRegisterCachePolicy cache_policy)
 {
 	g_return_if_fail (viewer != NULL);
 
@@ -208,6 +226,7 @@ arv_viewer_set_options (ArvViewer *viewer,
 	viewer->packet_resend = packet_resend;
 	viewer->packet_timeout = packet_timeout;
 	viewer->frame_retention = frame_retention;
+	viewer->cache_policy = cache_policy;
 }
 
 static double
@@ -236,8 +255,37 @@ arv_viewer_value_from_log (double value, double min, double max)
 	return pow (10.0, (value * (log10 (max) - log10 (min)) + log10 (min)));
 }
 
+typedef struct {
+	GWeakRef stream;
+	ArvBuffer* arv_buffer;
+} ArvGstBufferReleaseData;
+
+static void
+gst_buffer_release_cb (void *user_data)
+{
+	ArvGstBufferReleaseData* release_data = user_data;
+
+	ArvStream* stream = g_weak_ref_get (&release_data->stream);
+
+	if (stream) {
+		gint n_input_buffers, n_output_buffers;
+
+		arv_stream_get_n_buffers (stream, &n_input_buffers, &n_output_buffers);
+		arv_log_viewer ("push_buffer (%d,%d)", n_input_buffers, n_output_buffers);
+
+		arv_stream_push_buffer (stream, release_data->arv_buffer);
+		g_object_unref (stream);
+	} else {
+		arv_debug_viewer ("invalid stream object");
+		g_object_unref (release_data->arv_buffer);
+	}
+
+	g_weak_ref_clear (&release_data->stream);
+	g_free (release_data);
+}
+
 static GstBuffer *
-arv_to_gst_buffer (ArvBuffer *arv_buffer)
+arv_to_gst_buffer (ArvBuffer *arv_buffer, ArvStream *stream)
 {
 	GstBuffer *buffer;
 	int arv_row_stride;
@@ -266,9 +314,15 @@ arv_to_gst_buffer (ArvBuffer *arv_buffer)
 
 		buffer = gst_buffer_new_wrapped (data, size);
 	} else {
+		ArvGstBufferReleaseData* release_data = g_new0 (ArvGstBufferReleaseData, 1);
+
+		g_weak_ref_init (&release_data->stream, stream);
+		release_data->arv_buffer = arv_buffer;
+
 		buffer = gst_buffer_new_wrapped_full (GST_MEMORY_FLAG_READONLY,
 						      buffer_data, buffer_size,
-						      0, buffer_size, NULL, NULL);
+						      0, buffer_size,
+						      release_data, gst_buffer_release_cb);
 	}
 
 	return buffer;
@@ -278,17 +332,30 @@ static void
 new_buffer_cb (ArvStream *stream, ArvViewer *viewer)
 {
 	ArvBuffer *arv_buffer;
+	gint n_input_buffers, n_output_buffers;
 
 	arv_buffer = arv_stream_pop_buffer (stream);
 	if (arv_buffer == NULL)
 		return;
 
-	if (arv_buffer_get_status (arv_buffer) == ARV_BUFFER_STATUS_SUCCESS)
-		gst_app_src_push_buffer (GST_APP_SRC (viewer->appsrc), arv_to_gst_buffer (arv_buffer));
+	arv_stream_get_n_buffers (stream, &n_input_buffers, &n_output_buffers);
+	arv_log_viewer ("pop_buffer (%d,%d)", n_input_buffers, n_output_buffers);
 
-	if (viewer->last_buffer != NULL)
-		arv_stream_push_buffer (stream, viewer->last_buffer);
-	viewer->last_buffer = arv_buffer;
+	if (arv_buffer_get_status (arv_buffer) == ARV_BUFFER_STATUS_SUCCESS) {
+		size_t size;
+
+		arv_buffer_get_data (arv_buffer, &size);
+		gst_app_src_push_buffer (GST_APP_SRC (viewer->appsrc), arv_to_gst_buffer (arv_buffer, stream));
+
+		g_clear_object( &viewer->last_buffer );
+		viewer->last_buffer = g_object_ref( arv_buffer );
+
+		viewer->n_images++;
+		viewer->n_bytes += size;
+	} else {
+		arv_stream_push_buffer (stream, arv_buffer);
+		viewer->n_errors++;
+	}
 }
 
 static void
@@ -562,12 +629,46 @@ stream_cb (void *user_data, ArvStreamCallbackType type, ArvBuffer *buffer)
 	}
 }
 
+static gboolean
+update_status_bar_cb (void *data)
+{
+	ArvViewer *viewer = data;
+	char *text;
+	gint64 time_ms = g_get_real_time () / 1000;
+	gint64 elapsed_time_ms = time_ms - viewer->last_status_bar_update_time_ms;
+	guint n_images = viewer->n_images;
+	guint n_bytes = viewer->n_bytes;
+	guint n_errors = viewer->n_errors;
+
+	if (elapsed_time_ms == 0)
+		return TRUE;
+
+	text = g_strdup_printf ("%.1f fps (%.1f MB/s)",
+				1000.0 * (n_images - viewer->last_n_images) / elapsed_time_ms,
+				((n_bytes - viewer->last_n_bytes) / 1000.0) / elapsed_time_ms);
+	gtk_label_set_label (GTK_LABEL (viewer->fps_label), text);
+	g_free (text);
+
+	text = g_strdup_printf ("%u image%s / %u error%s",
+				n_images, n_images > 0 ? "s" : "",
+				n_errors, n_errors > 0 ? "s" : "");
+	gtk_label_set_label (GTK_LABEL (viewer->image_label), text);
+	g_free (text);
+
+	viewer->last_status_bar_update_time_ms = time_ms;
+	viewer->last_n_images = n_images;
+	viewer->last_n_bytes = n_bytes;
+
+	return TRUE;
+}
+
 static void
 update_camera_region (ArvViewer *viewer)
 {
 	gint x, y, width, height;
 	gint dx, dy;
 	gint min, max;
+	gint inc;
 
 	g_signal_handler_block (viewer->camera_x, viewer->camera_x_changed);
 	g_signal_handler_block (viewer->camera_y, viewer->camera_y_changed);
@@ -580,28 +681,40 @@ update_camera_region (ArvViewer *viewer)
 	arv_camera_get_binning (viewer->camera, &dx, &dy);
 
 	arv_camera_get_x_binning_bounds (viewer->camera, &min, &max);
+	inc = arv_camera_get_x_binning_increment (viewer->camera);
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->camera_binning_x), min, max);
-	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_binning_x), 1, 10);
+	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_binning_x), inc, inc * 10);
+	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (viewer->camera_binning_x), TRUE);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (viewer->camera_binning_x), dx);
 	arv_camera_get_y_binning_bounds (viewer->camera, &min, &max);
+	inc = arv_camera_get_y_binning_increment (viewer->camera);
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->camera_binning_y), min, max);
-	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_binning_y), 1, 10);
+	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_binning_y), inc, inc * 10);
+	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (viewer->camera_binning_y), TRUE);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (viewer->camera_binning_y), dy);
 	arv_camera_get_x_offset_bounds (viewer->camera, &min, &max);
+	inc = arv_camera_get_x_offset_increment (viewer->camera);
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->camera_x), min, max);
-	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_x), 1, 10);
+	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_x), inc, inc * 10);
+	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (viewer->camera_x), TRUE);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (viewer->camera_x), x);
 	arv_camera_get_y_offset_bounds (viewer->camera, &min, &max);
+	inc = arv_camera_get_y_offset_increment (viewer->camera);
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->camera_y), min, max);
-	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_y), 1, 10);
+	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_y), inc, inc * 10);
+	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (viewer->camera_y), TRUE);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (viewer->camera_y), y);
 	arv_camera_get_width_bounds (viewer->camera, &min, &max);
+	inc = arv_camera_get_width_increment (viewer->camera);
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->camera_width), min, max);
-	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_width), 1, 10);
+	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_width), inc, inc * 10);
+	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (viewer->camera_width), TRUE);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (viewer->camera_width), width);
 	arv_camera_get_height_bounds (viewer->camera, &min, &max);
+	inc = arv_camera_get_height_increment (viewer->camera);
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->camera_height), min, max);
-	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_height), 1, 10);
+	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->camera_height), inc, inc * 10);
+	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (viewer->camera_height), TRUE);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (viewer->camera_height), height);
 
 	g_signal_handler_unblock (viewer->camera_x, viewer->camera_x_changed);
@@ -710,6 +823,21 @@ stop_video (ArvViewer *viewer)
 		arv_camera_stop_acquisition (viewer->camera);
 
 	gtk_container_foreach (GTK_CONTAINER (viewer->video_frame), remove_widget, viewer->video_frame);
+
+	if (viewer->status_bar_update_event > 0) {
+		g_source_remove (viewer->status_bar_update_event);
+		viewer->status_bar_update_event = 0;
+	}
+
+	if (viewer->exposure_update_event > 0) {
+		g_source_remove (viewer->exposure_update_event);
+		viewer->exposure_update_event = 0;
+	}
+
+	if (viewer->gain_update_event > 0) {
+		g_source_remove (viewer->gain_update_event);
+		viewer->gain_update_event = 0;
+	}
 }
 
 static GstBusSyncReply
@@ -786,7 +914,7 @@ start_video (ArvViewer *viewer)
 
 	arv_stream_set_emit_signals (viewer->stream, TRUE);
 	payload = arv_camera_get_payload (viewer->camera);
-	for (i = 0; i < 50; i++)
+	for (i = 0; i < 5; i++)
 		arv_stream_push_buffer (viewer->stream, arv_buffer_new (payload, NULL));
 
 	arv_camera_get_region (viewer->camera, NULL, NULL, &width, &height);
@@ -940,6 +1068,14 @@ start_video (ArvViewer *viewer)
 
 	gst_element_set_state (viewer->pipeline, GST_STATE_PLAYING);
 
+	viewer->last_status_bar_update_time_ms = g_get_real_time () / 1000;
+	viewer->last_n_images = 0;
+	viewer->last_n_bytes = 0;
+	viewer->n_images = 0;
+	viewer->n_bytes = 0;
+	viewer->n_errors = 0;
+	viewer->status_bar_update_event = g_timeout_add_seconds (1, update_status_bar_cb, viewer);
+
 	g_signal_connect (viewer->stream, "new-buffer", G_CALLBACK (new_buffer_cb), viewer);
 
 	return TRUE;
@@ -990,6 +1126,8 @@ start_camera (ArvViewer *viewer, const char *camera_id)
 	if (!ARV_IS_CAMERA (viewer->camera))
 		return FALSE;
 
+	arv_device_set_register_cache_policy (arv_camera_get_device (viewer->camera), viewer->cache_policy);
+
 	viewer->camera_name = g_strdup (camera_id);
 
 	gtk_widget_set_sensitive (viewer->camera_parameters, TRUE);
@@ -1073,7 +1211,7 @@ select_mode (ArvViewer *viewer, ArvViewerMode mode)
 						    width, height,
 						    x, y,
 						    arv_camera_get_pixel_format_as_string (viewer->camera));
-			gtk_stack_set_visible_child (GTK_STACK (viewer->main_stack), viewer->video_frame);
+			gtk_stack_set_visible_child (GTK_STACK (viewer->main_stack), viewer->video_box);
 			gtk_header_bar_set_title (GTK_HEADER_BAR (viewer->main_headerbar), viewer->camera_name);
 			gtk_header_bar_set_subtitle (GTK_HEADER_BAR (viewer->main_headerbar), subtitle);
 			g_free (subtitle);
@@ -1108,33 +1246,28 @@ switch_to_video_mode_cb (GtkToolButton *button, ArvViewer *viewer)
 void
 arv_viewer_quit_cb (GtkApplicationWindow *window, ArvViewer *viewer)
 {
+	stop_camera (viewer);
 	g_application_quit (G_APPLICATION (viewer));
 }
 
 static void
 video_frame_realize_cb (GtkWidget * widget, ArvViewer *viewer)
 {
+#ifdef GDK_WINDOWING_X11
 	viewer->video_window_xid = GDK_WINDOW_XID (gtk_widget_get_window (widget));
+#endif
+#ifdef GDK_WINDOWING_WIN32
+	viewer->video_window_xid = (guintptr) GDK_WINDOW_HWND (gtk_widget_get_window (video_window));
+#endif
 }
 
 static void
 activate (GApplication *application)
 {
 	ArvViewer *viewer = (ArvViewer *) application;
-	GtkBuilder *builder;
-	char *ui_filename;
-	GError *err = NULL;
+	g_autoptr (GtkBuilder) builder;
 
-	builder = gtk_builder_new ();
-
-	ui_filename = g_build_filename (ARAVIS_DATA_DIR, "arv-viewer.ui", NULL);
-
-	if (!gtk_builder_add_from_file (builder, ui_filename, &err)) {
-		g_error ("Cant't load user interface file: %s", err->message);
-		g_error_free (err);
-	}
-
-	g_free (ui_filename);
+	builder = gtk_builder_new_from_resource ("/org/aravis/viewer/arv-viewer.ui");
 
 	viewer->main_window = GTK_WIDGET (gtk_builder_get_object (builder, "main_window"));
 	viewer->main_stack = GTK_WIDGET (gtk_builder_get_object (builder, "main_stack"));
@@ -1153,7 +1286,10 @@ activate (GApplication *application)
 	viewer->camera_binning_y = GTK_WIDGET (gtk_builder_get_object (builder, "camera_binning_y"));
 	viewer->camera_width = GTK_WIDGET (gtk_builder_get_object (builder, "camera_width"));
 	viewer->camera_height = GTK_WIDGET (gtk_builder_get_object (builder, "camera_height"));
+	viewer->video_box = GTK_WIDGET (gtk_builder_get_object (builder, "video_box"));
 	viewer->video_frame = GTK_WIDGET (gtk_builder_get_object (builder, "video_frame"));
+	viewer->fps_label = GTK_WIDGET (gtk_builder_get_object (builder, "fps_label"));
+	viewer->image_label = GTK_WIDGET (gtk_builder_get_object (builder, "image_label"));
 	viewer->trigger_combo_box = GTK_WIDGET (gtk_builder_get_object (builder, "trigger_combobox"));
 	viewer->frame_rate_entry = GTK_WIDGET (gtk_builder_get_object (builder, "frame_rate_entry"));
 	viewer->exposure_spin_button = GTK_WIDGET (gtk_builder_get_object (builder, "exposure_spinbutton"));
@@ -1167,8 +1303,6 @@ activate (GApplication *application)
 	viewer->flip_horizontal_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "flip_horizontal_togglebutton"));
 	viewer->acquisition_button = GTK_WIDGET (gtk_builder_get_object (builder, "acquisition_button"));
 
-	g_object_unref (builder);
-
 	gtk_widget_set_no_show_all (viewer->trigger_combo_box, TRUE);
 
 	gtk_widget_show_all (viewer->main_window);
@@ -1278,6 +1412,7 @@ arv_viewer_init (ArvViewer *viewer)
 	viewer->packet_resend = TRUE;
 	viewer->packet_timeout = 20;
 	viewer->frame_retention = 100;
+	viewer->cache_policy = ARV_REGISTER_CACHE_POLICY_DEFAULT;
 }
 
 static void
